#!/usr/bin/env python3

"""UIColor colorset extension generator

Searches recursively for *.colorset directories and generates Swift code
containing color definitions via UIColor extension.
"""

import os
import pathlib

# find colors

color_names = []

for dirpath, dirnames, filenames in os.walk('.'):
    pure_path = pathlib.PurePath(dirpath)
    directory_name = pure_path.name
    if '.colorset' in directory_name:
        color_names.append(pure_path.stem)

# build color definitions

color_definitions = list(map(lambda x: "static let {} = UIColor(named: \"{}\")".format(x, x) , color_names))

# compose file content

file_content = "// ******** Autogenerated File ******** //\n\n"
file_content += "import UIKit\n\n"
file_content += "extension UIColor {\n\n"

for color_definition in color_definitions:
    file_content += "    " + color_definition + "!\n"

file_content += "}"

print(file_content)
